#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tostring
version:              0.2.1.1
visibility:           public
id:                   tostring-0.2.1.1-IhJOXljrxNoF6L7XSMi75I
key:                  tostring-0.2.1.1-IhJOXljrxNoF6L7XSMi75I
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk B.V.
synopsis:             The ToString class
description:          A type class for converting text types to String.
category:             Data
abi:                  f29095806314b298f8cee85da731959c
exposed:              True
exposed-modules:      Data.String.ToString
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tostring
hs-libraries:         HStostring-0.2.1.1-IhJOXljrxNoF6L7XSMi75I
depends:
    base-4.18.2.1 case-insensitive-1.2.1.0-5z8pg5dkh9iJJTZAXWxvrE
    text-2.0.2 utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:   /usr/share/doc/haskell-tostring/html/tostring.haddock
haddock-html:         /usr/share/doc/haskell-tostring/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

